==> kdevelop-php-21.12.3-1-x86_64.pkg.tar.zst: usr/lib/cmake/KDevPHP/KDevPHPTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kdevphpparser" for configuration ""
set_property(TARGET kdevphpparser APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(kdevphpparser PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDev::Language;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdevphpparser.so"
  IMPORTED_SONAME_NOCONFIG "libkdevphpparser.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpparser )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpparser "${_IMPORT_PREFIX}/lib/libkdevphpparser.so" )

# Import target "kdevphpduchain" for configuration ""
set_property(TARGET kdevphpduchain APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(kdevphpduchain PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDev::Interfaces;KDev::Language;KDev::Shell;KDev::Project;kdevphpparser"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so"
  IMPORTED_SONAME_NOCONFIG "libkdevphpduchain.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpduchain )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpduchain "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so" )

# Import target "kdevphpcompletion" for configuration ""
set_property(TARGET kdevphpcompletion APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(kdevphpcompletion PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDev::Language;KDev::Interfaces;KDev::Project;kdevphpduchain;kdevphpparser"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so"
  IMPORTED_SONAME_NOCONFIG "libkdevphpcompletion.so"
  )

list(APPEND _IMPORT_CHECK_TARGETS kdevphpcompletion )
list(APPEND _IMPORT_CHECK_FILES_FOR_kdevphpcompletion "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kdevelop-php-24.01.90-1-x86_64.pkg.tar.zst: usr/lib/cmake/KDevPHP/KDevPHPTargets-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "kdevphpparser" for configuration ""
set_property(TARGET kdevphpparser APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(kdevphpparser PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDev::Language;KF5::I18n"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdevphpparser.so"
  IMPORTED_SONAME_NOCONFIG "libkdevphpparser.so"
  )

list(APPEND _cmake_import_check_targets kdevphpparser )
list(APPEND _cmake_import_check_files_for_kdevphpparser "${_IMPORT_PREFIX}/lib/libkdevphpparser.so" )

# Import target "kdevphpduchain" for configuration ""
set_property(TARGET kdevphpduchain APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(kdevphpduchain PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDev::Interfaces;KDev::Language;KDev::Shell;KDev::Project;kdevphpparser"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so"
  IMPORTED_SONAME_NOCONFIG "libkdevphpduchain.so"
  )

list(APPEND _cmake_import_check_targets kdevphpduchain )
list(APPEND _cmake_import_check_files_for_kdevphpduchain "${_IMPORT_PREFIX}/lib/libkdevphpduchain.so" )

# Import target "kdevphpcompletion" for configuration ""
set_property(TARGET kdevphpcompletion APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(kdevphpcompletion PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KDev::Language;KDev::Interfaces;KDev::Project;kdevphpduchain;kdevphpparser"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so"
  IMPORTED_SONAME_NOCONFIG "libkdevphpcompletion.so"
  )

list(APPEND _cmake_import_check_targets kdevphpcompletion )
list(APPEND _cmake_import_check_files_for_kdevphpcompletion "${_IMPORT_PREFIX}/lib/libkdevphpcompletion.so" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
